@@ -20,11 +20,11 @@ SequencesParser <- R6::R6Class(
     get_sequence_rec = function(r, drug_key) {
       tibble(
         sequence = xmlValue(r),
-        format = ifelse(is.null(xmlGetAttr(r, name = "format")),
-                        NA,
-                        xmlGetAttr(r, name = "format")
+        format   = ifelse(is.null(xmlGetAttr(r, name = "format")),
+                          NA,
+                          xmlGetAttr(r, name = "format")
         ),
-        parent_key = drug_key
+        drugbank_id = drug_key
       )
     }
   )
